==> mysql-5.6.49.tar.gz: mysql-5.6.49/storage/ndb/src/common/debugger/signaldata/FsConf.cpp <==
/*
   Copyright (C) 2003, 2005, 2006 MySQL AB
    All rights reserved. Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/



#include <signaldata/FsConf.hpp>

bool 
printFSCONF(FILE * output, const Uint32 * theData, Uint32 len, Uint16 receiverBlockNo){
  
  const FsConf * const sig = (FsConf *) theData;
  
  fprintf(output, " UserPointer: %d\n", sig->userPointer);

  if (len > 1){
    // Only valid if this is a FSOPENCONF
    fprintf(output, " FilePointer: %d\n", sig->filePointer);
  }
  return true;
}

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/storage/ndb/src/common/debugger/signaldata/FsConf.cpp <==
/* Copyright (c) 2003, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include <signaldata/FsConf.hpp>

bool printFSCONF(FILE *output, const Uint32 *theData, Uint32 len,
                 Uint16 /*receiverBlockNo*/) {
  const FsConf *const sig = (const FsConf *)theData;

  fprintf(output, " UserPointer: %d\n", sig->userPointer);

  if (len > 1) {
    // Only valid if this is a FSOPENCONF
    fprintf(output, " FilePointer/Bytes_read: %d\n", sig->filePointer);
  }

  if (len > 2) {
    fprintf(output, " FileInfo: %08x\n", sig->fileInfo);
  }

  return true;
}
